@@ -1,5 +1,7 @@
 """CLI utility helpers for tmuxp."""
 
+from __future__ import annotations
+
 import logging
 import re
 import typing as t
@@ -7,16 +9,17 @@ import typing as t
 from tmuxp import log
 
 if t.TYPE_CHECKING:
-    from typing_extensions import TypeAlias
+    from collections.abc import Callable, Sequence
+    from typing import TypeAlias
 
-    CLIColour: TypeAlias = t.Union[int, t.Tuple[int, int, int], str]
+    CLIColour: TypeAlias = int | tuple[int, int, int] | str
 
 
 logger = logging.getLogger(__name__)
 
 
 def tmuxp_echo(
-    message: t.Optional[str] = None,
+    message: str | None = None,
     log_level: str = "INFO",
     style_log: bool = False,
 ) -> None:
@@ -29,13 +32,13 @@ def tmuxp_echo(
     else:
         logger.log(log.LOG_LEVELS[log_level], unstyle(message))
 
-    print(message)
+    print(message)  # NOQA: T201 RUF100
 
 
 def prompt(
     name: str,
-    default: t.Optional[str] = None,
-    value_proc: t.Optional[t.Callable[[str], str]] = None,
+    default: str | None = None,
+    value_proc: Callable[[str], str] | None = None,
 ) -> str:
     """Return user input from command line.
 
@@ -56,10 +59,10 @@ def prompt(
     `flask-script <https://github.com/techniq/flask-script>`_. See the
     `flask-script license <https://github.com/techniq/flask-script/blob/master/LICENSE>`_.
     """
-    _prompt = name + ((default and " [%s]" % default) or "")
-    _prompt += (name.endswith("?") and " ") or ": "
+    prompt_ = name + ((default and f" [{default}]") or "")
+    prompt_ += (name.endswith("?") and " ") or ": "
     while True:
-        rv = input(_prompt) or default
+        rv = input(prompt_) or default
         try:
             if value_proc is not None and callable(value_proc):
                 assert isinstance(rv, str)
@@ -76,8 +79,8 @@ def prompt(
 def prompt_bool(
     name: str,
     default: bool = False,
-    yes_choices: t.Optional[t.Sequence[t.Any]] = None,
-    no_choices: t.Optional[t.Sequence[t.Any]] = None,
+    yes_choices: Sequence[t.Any] | None = None,
+    no_choices: Sequence[t.Any] | None = None,
 ) -> bool:
     """Return True / False by prompting user input from command line.
 
@@ -106,11 +109,11 @@ def prompt_bool(
     else:
         prompt_choice = "y/N"
 
-    _prompt = name + " [%s]" % prompt_choice
-    _prompt += (name.endswith("?") and " ") or ": "
+    prompt_ = name + f" [{prompt_choice}]"
+    prompt_ += (name.endswith("?") and " ") or ": "
 
     while True:
-        rv = input(_prompt)
+        rv = input(prompt_)
         if not rv:
             return default
         if rv.lower() in yes_choices:
@@ -126,10 +129,10 @@ def prompt_yes_no(name: str, default: bool = True) -> bool:
 
 def prompt_choices(
     name: str,
-    choices: t.Union[t.List[str], t.Tuple[str, str]],
-    default: t.Optional[str] = None,
-    no_choice: t.Sequence[str] = ("none",),
-) -> t.Optional[str]:
+    choices: list[str] | tuple[str, str],
+    default: str | None = None,
+    no_choice: Sequence[str] = ("none",),
+) -> str | None:
     """Return user input from command line from set of provided choices.
 
     Parameters
@@ -148,8 +151,8 @@ def prompt_choices(
     -------
     str
     """
-    _choices: t.List[str] = []
-    options: t.List[str] = []
+    choices_: list[str] = []
+    options: list[str] = []
 
     for choice in choices:
         if isinstance(choice, str):
@@ -157,16 +160,16 @@ def prompt_choices(
         elif isinstance(choice, tuple):
             options.append(f"{choice} [{choice[0]}]")
             choice = choice[0]
-        _choices.append(choice)
+        choices_.append(choice)
 
     while True:
-        rv = prompt(name + " - (%s)" % ", ".join(options), default=default)
+        rv = prompt(name + " - ({})".format(", ".join(options)), default=default)
         if not rv or rv == default:
             return default
         rv = rv.lower()
         if rv in no_choice:
             return None
-        if rv in _choices:
+        if rv in choices_:
             return rv
 
 
@@ -201,7 +204,7 @@ _ansi_reset_all = "\033[0m"
 
 
 def _interpret_color(
-    color: t.Union[int, t.Tuple[int, int, int], str],
+    color: int | tuple[int, int, int] | str,
     offset: int = 0,
 ) -> str:
     if isinstance(color, int):
@@ -217,22 +220,22 @@ def _interpret_color(
 class UnknownStyleColor(Exception):
     """Raised when encountering an unknown terminal style color."""
 
-    def __init__(self, color: "CLIColour", *args: object, **kwargs: object) -> None:
+    def __init__(self, color: CLIColour, *args: object, **kwargs: object) -> None:
         return super().__init__(f"Unknown color {color!r}", *args, **kwargs)
 
 
 def style(
     text: t.Any,
-    fg: t.Optional["CLIColour"] = None,
-    bg: t.Optional["CLIColour"] = None,
-    bold: t.Optional[bool] = None,
-    dim: t.Optional[bool] = None,
-    underline: t.Optional[bool] = None,
-    overline: t.Optional[bool] = None,
-    italic: t.Optional[bool] = None,
-    blink: t.Optional[bool] = None,
-    reverse: t.Optional[bool] = None,
-    strikethrough: t.Optional[bool] = None,
+    fg: CLIColour | None = None,
+    bg: CLIColour | None = None,
+    bold: bool | None = None,
+    dim: bool | None = None,
+    underline: bool | None = None,
+    overline: bool | None = None,
+    italic: bool | None = None,
+    blink: bool | None = None,
+    reverse: bool | None = None,
+    strikethrough: bool | None = None,
     reset: bool = True,
 ) -> str:
     """Credit: click."""
